@@ -13,10 +13,11 @@ from httpie.client import collect_messages
 from httpie.context import Environment
 from httpie.downloads import Downloader
 from httpie.output.writer import write_message, write_stream
-from httpie.plugins import plugin_manager
+from httpie.plugins.registry import plugin_manager
 from httpie.status import ExitStatus, http_status_to_exit_status
 
 
+# noinspection PyDefaultArgument
 def main(
     args: List[Union[str, bytes]] = sys.argv,
     env=Environment(),
@@ -90,7 +91,7 @@ def main(
             exit_status = ExitStatus.ERROR_TOO_MANY_REDIRECTS
             env.log_error(
                 f'Too many redirects'
-                f' (--max-redirects=parsed_args.max_redirects).'
+                f' (--max-redirects={parsed_args.max_redirects}).'
             )
         except Exception as e:
             # TODO: Further distinction between expected and unexpected errors.
